@@ -76,41 +76,44 @@ const struct
     DP_REG_VAL_TYPE valueType;
 } DP_REGKEY_TABLE [] =
 {
-    {NV_DP_REGKEY_OVERRIDE_DPCD_REV,                     &dpRegkeyDatabase.dpcdRevOveride,                    DP_REG_VAL_U32},
-    {NV_DP_REGKEY_DISABLE_SSC,                           &dpRegkeyDatabase.bSscDisabled,                      DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_FAST_LINK_TRAINING,             &dpRegkeyDatabase.bFastLinkTrainingEnabled,          DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_DISABLE_MST,                           &dpRegkeyDatabase.bMstDisabled,                      DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_INBAND_STEREO_SIGNALING,        &dpRegkeyDatabase.bInbandStereoSignalingEnabled,     DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_SKIP_POWEROFF_EDP_IN_HEAD_DETACH,      &dpRegkeyDatabase.bPoweroffEdpInHeadDetachSkipped,   DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_OCA_LOGGING,                    &dpRegkeyDatabase.bOcaLoggingEnabled,                DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_REPORT_DEVICE_LOST_BEFORE_NEW,         &dpRegkeyDatabase.bReportDeviceLostBeforeNew,        DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_APPLY_LINK_BW_OVERRIDE_WAR,            &dpRegkeyDatabase.bLinkBwOverrideWarApplied,         DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_APPLY_MAX_LINK_RATE_OVERRIDES,         &dpRegkeyDatabase.applyMaxLinkRateOverrides,         DP_REG_VAL_U32},
-    {NV_DP_REGKEY_DISABLE_DSC,                           &dpRegkeyDatabase.bDscDisabled,                      DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_SKIP_ASSESSLINK_FOR_EDP,               &dpRegkeyDatabase.bAssesslinkForEdpSkipped,          DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_MST_AUTO_HDCP_AUTH_AT_ATTACH,          &dpRegkeyDatabase.bMstAutoHdcpAuthAtAttach,          DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_MSA_OVER_MST,                   &dpRegkeyDatabase.bMsaOverMstEnabled,                DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE,                   &dpRegkeyDatabase.bOptLinkKeptAlive,                 DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE_MST,               &dpRegkeyDatabase.bOptLinkKeptAliveMst,              DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE_SST,               &dpRegkeyDatabase.bOptLinkKeptAliveSst,              DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_FORCE_EDP_ILR,                         &dpRegkeyDatabase.bBypassEDPRevCheck,                DP_REG_VAL_BOOL},
-    {NV_DP_DSC_MST_CAP_BUG_3143315,                      &dpRegkeyDatabase.bDscMstCapBug3143315,              DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_POWER_DOWN_PHY,                        &dpRegkeyDatabase.bPowerDownPhyBeforeD3,             DP_REG_VAL_BOOL},
-    {NV_DP2X_REGKEY_FPGA_UHBR_SUPPORT,                   &dpRegkeyDatabase.supportInternalUhbrOnFpga,         DP_REG_VAL_U32},
-    {NV_DP2X_IGNORE_CABLE_ID_CAPS,                       &dpRegkeyDatabase.bIgnoreCableIdCaps,                DP_REG_VAL_BOOL},
-    {NV_DP2X_REGKEY_VCONN_SOURCE_UNKNOWN_WAR,            &dpRegkeyDatabase.bCableVconnSourceUnknownWar,       DP_REG_VAL_BOOL},
-    {NV_DP2X_REGKEY_DISABLE_EFF_BPP_SST_8b10b,           &dpRegkeyDatabase.bDisableEffBppSST8b10b,            DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_MST_PCON_CAPS_READ_DISABLED,           &dpRegkeyDatabase.bMSTPCONCapsReadDisabled,          DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_DISABLE_TUNNEL_BW_ALLOCATION,          &dpRegkeyDatabase.bForceDisableTunnelBwAllocation,   DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_DISABLE_DOWNSPREAD,                    &dpRegkeyDatabase.bDownspreadDisabled,               DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_DISABLE_AVOID_HBR3_WAR,                &dpRegkeyDatabase.bDisableAvoidHBR3War,              DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_SKIP_ZERO_OUI_CACHE,                   &dpRegkeyDatabase.bSkipZeroOuiCache,                 DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_FIX_FOR_5147205,                &dpRegkeyDatabase.bEnable5147205Fix,                 DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_FORCE_HEAD_SHUTDOWN,                   &dpRegkeyDatabase.bForceHeadShutdown,                DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_EXPOSE_DSC_DEVID_WAR,                  &dpRegkeyDatabase.bEnableDevId,                      DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_HDMI_ON_DP_PLUS_PLUS,                  &dpRegkeyDatabase.bHDMIOnDPPlusPlus,                 DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_IGNORE_CAPS_AND_FORCE_HIGHEST_LC,      &dpRegkeyDatabase.bIgnoreCapsAndForceHighestLc,      DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_OPTIMIZE_DSC_BPP_FOR_TUNNELLING_BW,    &dpRegkeyDatabase.bOptimizeDscBppForTunnellingBw,    DP_REG_VAL_BOOL}
+    {NV_DP_REGKEY_OVERRIDE_DPCD_REV,                      &dpRegkeyDatabase.dpcdRevOveride,                     DP_REG_VAL_U32},
+    {NV_DP_REGKEY_DISABLE_SSC,                            &dpRegkeyDatabase.bSscDisabled,                       DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_FAST_LINK_TRAINING,              &dpRegkeyDatabase.bFastLinkTrainingEnabled,           DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_MST,                            &dpRegkeyDatabase.bMstDisabled,                       DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_INBAND_STEREO_SIGNALING,         &dpRegkeyDatabase.bInbandStereoSignalingEnabled,      DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_SKIP_POWEROFF_EDP_IN_HEAD_DETACH,       &dpRegkeyDatabase.bPoweroffEdpInHeadDetachSkipped,    DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_OCA_LOGGING,                     &dpRegkeyDatabase.bOcaLoggingEnabled,                 DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_REPORT_DEVICE_LOST_BEFORE_NEW,          &dpRegkeyDatabase.bReportDeviceLostBeforeNew,         DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_APPLY_LINK_BW_OVERRIDE_WAR,             &dpRegkeyDatabase.bLinkBwOverrideWarApplied,          DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_APPLY_MAX_LINK_RATE_OVERRIDES,          &dpRegkeyDatabase.applyMaxLinkRateOverrides,          DP_REG_VAL_U32},
+    {NV_DP_REGKEY_DISABLE_DSC,                            &dpRegkeyDatabase.bDscDisabled,                       DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_SKIP_ASSESSLINK_FOR_EDP,                &dpRegkeyDatabase.bAssesslinkForEdpSkipped,           DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_MST_AUTO_HDCP_AUTH_AT_ATTACH,           &dpRegkeyDatabase.bMstAutoHdcpAuthAtAttach,           DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_MSA_OVER_MST,                    &dpRegkeyDatabase.bMsaOverMstEnabled,                 DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE,                    &dpRegkeyDatabase.bOptLinkKeptAlive,                  DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE_MST,                &dpRegkeyDatabase.bOptLinkKeptAliveMst,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_KEEP_OPT_LINK_ALIVE_SST,                &dpRegkeyDatabase.bOptLinkKeptAliveSst,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_FORCE_EDP_ILR,                          &dpRegkeyDatabase.bBypassEDPRevCheck,                 DP_REG_VAL_BOOL},
+    {NV_DP_DSC_MST_CAP_BUG_3143315,                       &dpRegkeyDatabase.bDscMstCapBug3143315,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_POWER_DOWN_PHY,                         &dpRegkeyDatabase.bPowerDownPhyBeforeD3,              DP_REG_VAL_BOOL},
+    {NV_DP2X_REGKEY_FPGA_UHBR_SUPPORT,                    &dpRegkeyDatabase.supportInternalUhbrOnFpga,          DP_REG_VAL_U32},
+    {NV_DP2X_IGNORE_CABLE_ID_CAPS,                        &dpRegkeyDatabase.bIgnoreCableIdCaps,                 DP_REG_VAL_BOOL},
+    {NV_DP2X_REGKEY_VCONN_SOURCE_UNKNOWN_WAR,             &dpRegkeyDatabase.bCableVconnSourceUnknownWar,        DP_REG_VAL_BOOL},
+    {NV_DP2X_REGKEY_DISABLE_EFF_BPP_SST_8b10b,            &dpRegkeyDatabase.bDisableEffBppSST8b10b,             DP_REG_VAL_BOOL},
+    {NV_DP2X_REGKEY_DISABLE_WATERMARK_CACHING,            &dpRegkeyDatabase.bDisableWatermarkCaching,           DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_MST_PCON_CAPS_READ_DISABLED,            &dpRegkeyDatabase.bMSTPCONCapsReadDisabled,           DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_TUNNEL_BW_ALLOCATION,           &dpRegkeyDatabase.bForceDisableTunnelBwAllocation,    DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_DOWNSPREAD,                     &dpRegkeyDatabase.bDownspreadDisabled,                DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_AVOID_HBR3_WAR,                 &dpRegkeyDatabase.bDisableAvoidHBR3War,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_SKIP_ZERO_OUI_CACHE,                    &dpRegkeyDatabase.bSkipZeroOuiCache,                  DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_FIX_FOR_5147205,                 &dpRegkeyDatabase.bEnable5147205Fix,                  DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_FORCE_HEAD_SHUTDOWN,                    &dpRegkeyDatabase.bForceHeadShutdown,                 DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_EXPOSE_DSC_DEVID_WAR,                   &dpRegkeyDatabase.bEnableDevId,                       DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_CQA_STATS_COLLECTION,            &dpRegkeyDatabase.bEnableCqaStatsCollection,          DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_IGNORE_CAPS_AND_FORCE_HIGHEST_LC,       &dpRegkeyDatabase.bIgnoreCapsAndForceHighestLc,       DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_OPTIMIZE_DSC_BPP_FOR_TUNNELLING_BW,     &dpRegkeyDatabase.bOptimizeDscBppForTunnellingBw,     DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_128b132b_DSC_LNK_CFG_REDUCTION,  &dpRegkeyDatabase.bEnable128b132bDSCLnkCfgReduction,  DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_USE_MAX_DSC_COMPRESSION_MST,            &dpRegkeyDatabase.bUseMaxDSCCompressionMST,           DP_REG_VAL_BOOL}
 };
 
 EvoMainLink::EvoMainLink(EvoInterface * provider, Timer * timer) :
